@@ -242,8 +242,9 @@ class Shell(HasRequiredTraits):
             )
             if mm is not None:
                 host_ip = mm.group(2)
-                assert stdlib_ip_factory(host_ip)  # This will raise a ValueError
-                print("MATCH host name to inventory", host_ip, line)
+                logger.debug("    inventory match: '%s' = '%s'" % (hostname.lower, host_ip))
+                tmp = stdlib_ip_factory(host_ip)  # This will raise a ValueError
+                print("MATCH host name with inventory", hostname, line)
                 return host_ip
 
         else:
